# Tutorials

Most of these tutorials have been produced by Ipython notebook.

```{toctree}
---
maxdepth: 2
---
ipynb/tuto_user
ipynb/tuto_dev
ipynb/executed/taylor-green
```

## Parametric study with fluidsim.solvers.ns3d.strat

```{toctree}
---
maxdepth: 2
---
ipynb/executed/parametric_study_ns3dstrat/0_run_simulations
ipynb/executed/parametric_study_ns3dstrat/1_analyze_1_simul
ipynb/executed/parametric_study_ns3dstrat/2_compare_simulations
```
